11. Licenses — setupjavax documentation

# 11. Licenses

## 11.1. Product

Product Data

- MISSION=Support Java extensions for setuptools / distutils.

- AUTHOR=Arno-Can Uestuensoez

- PROJECT=setupjavax

- COPYRIGHT=(C)2019 Arno-Can Uestuensoez

- LICENSE=Artistic-License-2.0 + Forced-Fairplay-Constraints

- VERSION=0.1.37

- RELEASE=0.1.37

- STATUS=Unknown

- BUILDDATE=2019.12.09-05:53

## 11.2. Modified Artistic License

The modified Artistic License is based on the ArtisticLicense2.0, but adds the amendmend of “Forced-Fairplay-Constraints” for peer-to-peer fairplay rules. The modification restricts, and even revokes the permission including the open source attribution in case of breaches, including the past.

    License: ModifiedArtisticLicense2.0 = ArtisticLicense20 + licenses-amendments
    From Ingenieurbuero Arno-Can Uestuensoez
    Name  ModifiedArtisticLicense2.0

This is perfectly allright, as you may refer to cases like the faith of Andreas Pavel [AndreasPavel], or even my own - UnifiedSessionsManager (C) 2008 Arno-Can Uestuensoez [UnifiedSessionsManager] - the first multivendor cloud management system, capable of distributed hybrid clouds including virtual desktops. The UnifiedSessionsManager was originally licensed as GPL3.

So the software is OpenSource as long as you comply to basic rules - else not.

- Artistic-License-2.0(base license): ArtisticLicense20

- Forced-Fairplay-Constraints(amendments): licenses-amendments

## 11.3. MIT License

The configuration files are licensed by the MIT license. Configuration files are “conf.py”, files ending with the suffixes “.conf”, “.cfg”, “.css”, “.ini”, “.json”, “xml”, and “.yaml”. The same for template files ending with “.html”.

The license for the project remains in any case the modified Artistic License. This includes any code, interface, document, and concept.

The MIT license for configuration files only MIT License.

## 11.4. Profile Abuse

> Profile Info - http://xkcd.com/1303/

> (C) Randall Munroe - http://xkcd.com